# coding: utf-8

"""
    Trackside Software TeamDB API v2.0

    This API enables you to access TeamDB data  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@trackside.fr
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from teamdbapi.configuration import Configuration


class ItemValueKey(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'model_field_id': 'str',
        'parent_item_id': 'str'
    }

    attribute_map = {
        'model_field_id': 'ModelFieldId',
        'parent_item_id': 'ParentItemId'
    }

    def __init__(self, model_field_id=None, parent_item_id=None, _configuration=None):  # noqa: E501
        """ItemValueKey - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._model_field_id = None
        self._parent_item_id = None
        self.discriminator = None

        self.model_field_id = model_field_id
        self.parent_item_id = parent_item_id

    @property
    def model_field_id(self):
        """Gets the model_field_id of this ItemValueKey.  # noqa: E501

        The model field id to which the value is linked  # noqa: E501

        :return: The model_field_id of this ItemValueKey.  # noqa: E501
        :rtype: str
        """
        return self._model_field_id

    @model_field_id.setter
    def model_field_id(self, model_field_id):
        """Sets the model_field_id of this ItemValueKey.

        The model field id to which the value is linked  # noqa: E501

        :param model_field_id: The model_field_id of this ItemValueKey.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and model_field_id is None:
            raise ValueError("Invalid value for `model_field_id`, must not be `None`")  # noqa: E501

        self._model_field_id = model_field_id

    @property
    def parent_item_id(self):
        """Gets the parent_item_id of this ItemValueKey.  # noqa: E501

        The id of the parent entity (event, car, session, run, lap) which owns the value.  # noqa: E501

        :return: The parent_item_id of this ItemValueKey.  # noqa: E501
        :rtype: str
        """
        return self._parent_item_id

    @parent_item_id.setter
    def parent_item_id(self, parent_item_id):
        """Sets the parent_item_id of this ItemValueKey.

        The id of the parent entity (event, car, session, run, lap) which owns the value.  # noqa: E501

        :param parent_item_id: The parent_item_id of this ItemValueKey.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and parent_item_id is None:
            raise ValueError("Invalid value for `parent_item_id`, must not be `None`")  # noqa: E501

        self._parent_item_id = parent_item_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ItemValueKey, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ItemValueKey):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ItemValueKey):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Trackside Software TeamDB API v2.0

    This API enables you to access TeamDB data  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@trackside.fr
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from teamdbapi.api_client import ApiClient


class TeamDBListApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def team_db_list_create_list_item(self, new_item, **kwargs):  # noqa: E501
        """Create a new TeamDB list item  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.team_db_list_create_list_item(new_item, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param TeamDBListItem new_item: The TeamDB list item to create. (required)
        :return: TeamDBListItem
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.team_db_list_create_list_item_with_http_info(new_item, **kwargs)  # noqa: E501
        else:
            (data) = self.team_db_list_create_list_item_with_http_info(new_item, **kwargs)  # noqa: E501
            return data

    def team_db_list_create_list_item_with_http_info(self, new_item, **kwargs):  # noqa: E501
        """Create a new TeamDB list item  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.team_db_list_create_list_item_with_http_info(new_item, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param TeamDBListItem new_item: The TeamDB list item to create. (required)
        :return: TeamDBListItem
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['new_item']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method team_db_list_create_list_item" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'new_item' is set
        if self.api_client.client_side_validation and ('new_item' not in params or
                                                       params['new_item'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `new_item` when calling `team_db_list_create_list_item`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'new_item' in params:
            body_params = params['new_item']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json-patch+json', 'application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/teamdblistitem', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TeamDBListItem',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def team_db_list_create_list(self, new_list, **kwargs):  # noqa: E501
        """Create a new TeamDB list  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.team_db_list_create_list(new_list, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param TeamDBList new_list: The TeamDB list to create. (required)
        :return: TeamDBList
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.team_db_list_create_list_with_http_info(new_list, **kwargs)  # noqa: E501
        else:
            (data) = self.team_db_list_create_list_with_http_info(new_list, **kwargs)  # noqa: E501
            return data

    def team_db_list_create_list_with_http_info(self, new_list, **kwargs):  # noqa: E501
        """Create a new TeamDB list  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.team_db_list_create_list_with_http_info(new_list, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param TeamDBList new_list: The TeamDB list to create. (required)
        :return: TeamDBList
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['new_list']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method team_db_list_create_list" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'new_list' is set
        if self.api_client.client_side_validation and ('new_list' not in params or
                                                       params['new_list'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `new_list` when calling `team_db_list_create_list`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'new_list' in params:
            body_params = params['new_list']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json-patch+json', 'application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/teamdblist', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TeamDBList',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def team_db_list_delete_list(self, list_id, **kwargs):  # noqa: E501
        """Delete an existing TeamDB list  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.team_db_list_delete_list(list_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str list_id: The unique TeamDB list id for which you want to delete the list (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.team_db_list_delete_list_with_http_info(list_id, **kwargs)  # noqa: E501
        else:
            (data) = self.team_db_list_delete_list_with_http_info(list_id, **kwargs)  # noqa: E501
            return data

    def team_db_list_delete_list_with_http_info(self, list_id, **kwargs):  # noqa: E501
        """Delete an existing TeamDB list  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.team_db_list_delete_list_with_http_info(list_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str list_id: The unique TeamDB list id for which you want to delete the list (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['list_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method team_db_list_delete_list" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'list_id' is set
        if self.api_client.client_side_validation and ('list_id' not in params or
                                                       params['list_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `list_id` when calling `team_db_list_delete_list`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'list_id' in params:
            path_params['listId'] = params['list_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/teamdblist/{listId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def team_db_list_delete_list_item(self, item_id, **kwargs):  # noqa: E501
        """Delete an existing TeamDB list item  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.team_db_list_delete_list_item(item_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str item_id: The unique TeamDB list item id for which you want to delete the item (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.team_db_list_delete_list_item_with_http_info(item_id, **kwargs)  # noqa: E501
        else:
            (data) = self.team_db_list_delete_list_item_with_http_info(item_id, **kwargs)  # noqa: E501
            return data

    def team_db_list_delete_list_item_with_http_info(self, item_id, **kwargs):  # noqa: E501
        """Delete an existing TeamDB list item  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.team_db_list_delete_list_item_with_http_info(item_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str item_id: The unique TeamDB list item id for which you want to delete the item (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['item_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method team_db_list_delete_list_item" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'item_id' is set
        if self.api_client.client_side_validation and ('item_id' not in params or
                                                       params['item_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `item_id` when calling `team_db_list_delete_list_item`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'item_id' in params:
            path_params['itemId'] = params['item_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/teamdblistitem/{itemId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def team_db_list_get_list_item(self, item_id, **kwargs):  # noqa: E501
        """Get a TeamDB list item via a unique id.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.team_db_list_get_list_item(item_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str item_id: The unique TeamDB list item id for which you want to get the item (required)
        :return: TeamDBListItem
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.team_db_list_get_list_item_with_http_info(item_id, **kwargs)  # noqa: E501
        else:
            (data) = self.team_db_list_get_list_item_with_http_info(item_id, **kwargs)  # noqa: E501
            return data

    def team_db_list_get_list_item_with_http_info(self, item_id, **kwargs):  # noqa: E501
        """Get a TeamDB list item via a unique id.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.team_db_list_get_list_item_with_http_info(item_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str item_id: The unique TeamDB list item id for which you want to get the item (required)
        :return: TeamDBListItem
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['item_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method team_db_list_get_list_item" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'item_id' is set
        if self.api_client.client_side_validation and ('item_id' not in params or
                                                       params['item_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `item_id` when calling `team_db_list_get_list_item`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'item_id' in params:
            path_params['itemId'] = params['item_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/teamdblistitem/{itemId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TeamDBListItem',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def team_db_list_get_list_items(self, list_id, **kwargs):  # noqa: E501
        """Get the list of all items for a TeamDB list  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.team_db_list_get_list_items(list_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str list_id: The unique TeamDB list id for which you want the items (required)
        :return: list[TeamDBListItem]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.team_db_list_get_list_items_with_http_info(list_id, **kwargs)  # noqa: E501
        else:
            (data) = self.team_db_list_get_list_items_with_http_info(list_id, **kwargs)  # noqa: E501
            return data

    def team_db_list_get_list_items_with_http_info(self, list_id, **kwargs):  # noqa: E501
        """Get the list of all items for a TeamDB list  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.team_db_list_get_list_items_with_http_info(list_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str list_id: The unique TeamDB list id for which you want the items (required)
        :return: list[TeamDBListItem]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['list_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method team_db_list_get_list_items" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'list_id' is set
        if self.api_client.client_side_validation and ('list_id' not in params or
                                                       params['list_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `list_id` when calling `team_db_list_get_list_items`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'list_id' in params:
            path_params['listId'] = params['list_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/teamdblist/{listId}/items', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[TeamDBListItem]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def team_db_list_get_list(self, list_id, **kwargs):  # noqa: E501
        """Get a TeamDB list via a unique id.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.team_db_list_get_list(list_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str list_id: The unique TeamDB list id for which you want to get the list (required)
        :return: TeamDBList
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.team_db_list_get_list_with_http_info(list_id, **kwargs)  # noqa: E501
        else:
            (data) = self.team_db_list_get_list_with_http_info(list_id, **kwargs)  # noqa: E501
            return data

    def team_db_list_get_list_with_http_info(self, list_id, **kwargs):  # noqa: E501
        """Get a TeamDB list via a unique id.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.team_db_list_get_list_with_http_info(list_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str list_id: The unique TeamDB list id for which you want to get the list (required)
        :return: TeamDBList
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['list_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method team_db_list_get_list" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'list_id' is set
        if self.api_client.client_side_validation and ('list_id' not in params or
                                                       params['list_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `list_id` when calling `team_db_list_get_list`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'list_id' in params:
            path_params['listId'] = params['list_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/teamdblist/{listId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TeamDBList',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def team_db_list_get_lists(self, **kwargs):  # noqa: E501
        """Get the list of all TeamDB lists  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.team_db_list_get_lists(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: list[TeamDBList]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.team_db_list_get_lists_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.team_db_list_get_lists_with_http_info(**kwargs)  # noqa: E501
            return data

    def team_db_list_get_lists_with_http_info(self, **kwargs):  # noqa: E501
        """Get the list of all TeamDB lists  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.team_db_list_get_lists_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: list[TeamDBList]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method team_db_list_get_lists" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/teamdblists', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[TeamDBList]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def team_db_list_update_list(self, list_id, updated_list, **kwargs):  # noqa: E501
        """Update an existing TeamDB list  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.team_db_list_update_list(list_id, updated_list, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str list_id: The unique TeamDB list id for which you want to update the list (required)
        :param TeamDBList updated_list: The TeamDB list to update. (required)
        :return: TeamDBList
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.team_db_list_update_list_with_http_info(list_id, updated_list, **kwargs)  # noqa: E501
        else:
            (data) = self.team_db_list_update_list_with_http_info(list_id, updated_list, **kwargs)  # noqa: E501
            return data

    def team_db_list_update_list_with_http_info(self, list_id, updated_list, **kwargs):  # noqa: E501
        """Update an existing TeamDB list  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.team_db_list_update_list_with_http_info(list_id, updated_list, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str list_id: The unique TeamDB list id for which you want to update the list (required)
        :param TeamDBList updated_list: The TeamDB list to update. (required)
        :return: TeamDBList
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['list_id', 'updated_list']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method team_db_list_update_list" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'list_id' is set
        if self.api_client.client_side_validation and ('list_id' not in params or
                                                       params['list_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `list_id` when calling `team_db_list_update_list`")  # noqa: E501
        # verify the required parameter 'updated_list' is set
        if self.api_client.client_side_validation and ('updated_list' not in params or
                                                       params['updated_list'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `updated_list` when calling `team_db_list_update_list`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'list_id' in params:
            path_params['listId'] = params['list_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'updated_list' in params:
            body_params = params['updated_list']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json-patch+json', 'application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/teamdblist/{listId}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TeamDBList',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def team_db_list_update_list_item(self, item_id, updated_list_item, **kwargs):  # noqa: E501
        """Update an existing TeamDB list item  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.team_db_list_update_list_item(item_id, updated_list_item, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str item_id: The unique TeamDB list item id for which you want to update the item (required)
        :param TeamDBListItem updated_list_item: The TeamDB list item to update. (required)
        :return: TeamDBListItem
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.team_db_list_update_list_item_with_http_info(item_id, updated_list_item, **kwargs)  # noqa: E501
        else:
            (data) = self.team_db_list_update_list_item_with_http_info(item_id, updated_list_item, **kwargs)  # noqa: E501
            return data

    def team_db_list_update_list_item_with_http_info(self, item_id, updated_list_item, **kwargs):  # noqa: E501
        """Update an existing TeamDB list item  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.team_db_list_update_list_item_with_http_info(item_id, updated_list_item, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str item_id: The unique TeamDB list item id for which you want to update the item (required)
        :param TeamDBListItem updated_list_item: The TeamDB list item to update. (required)
        :return: TeamDBListItem
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['item_id', 'updated_list_item']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method team_db_list_update_list_item" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'item_id' is set
        if self.api_client.client_side_validation and ('item_id' not in params or
                                                       params['item_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `item_id` when calling `team_db_list_update_list_item`")  # noqa: E501
        # verify the required parameter 'updated_list_item' is set
        if self.api_client.client_side_validation and ('updated_list_item' not in params or
                                                       params['updated_list_item'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `updated_list_item` when calling `team_db_list_update_list_item`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'item_id' in params:
            path_params['itemId'] = params['item_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'updated_list_item' in params:
            body_params = params['updated_list_item']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json-patch+json', 'application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/teamdblistitem/{itemId}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TeamDBListItem',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Trackside Software TeamDB API v2.0

    This API enables you to access TeamDB data  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@trackside.fr
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from teamdbapi.configuration import Configuration


class Group(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'name': 'str',
        'version_id': 'str',
        'parent_group_id': 'str',
        'last_update_date_utc': 'datetime',
        'last_update_user': 'str'
    }

    attribute_map = {
        'id': 'Id',
        'name': 'Name',
        'version_id': 'VersionId',
        'parent_group_id': 'ParentGroupId',
        'last_update_date_utc': 'LastUpdateDateUtc',
        'last_update_user': 'LastUpdateUser'
    }

    def __init__(self, id=None, name=None, version_id=None, parent_group_id=None, last_update_date_utc=None, last_update_user=None, _configuration=None):  # noqa: E501
        """Group - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._id = None
        self._name = None
        self._version_id = None
        self._parent_group_id = None
        self._last_update_date_utc = None
        self._last_update_user = None
        self.discriminator = None

        self.id = id
        self.name = name
        self.version_id = version_id
        if parent_group_id is not None:
            self.parent_group_id = parent_group_id
        if last_update_date_utc is not None:
            self.last_update_date_utc = last_update_date_utc
        if last_update_user is not None:
            self.last_update_user = last_update_user

    @property
    def id(self):
        """Gets the id of this Group.  # noqa: E501

        The unique group id.  Set the Id to Guid.Empty (00000000-0000-0000-0000-000000000000) if you want to create a new Group.  # noqa: E501

        :return: The id of this Group.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Group.

        The unique group id.  Set the Id to Guid.Empty (00000000-0000-0000-0000-000000000000) if you want to create a new Group.  # noqa: E501

        :param id: The id of this Group.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def name(self):
        """Gets the name of this Group.  # noqa: E501

        The group name. Must be unique for a given version.  # noqa: E501

        :return: The name of this Group.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Group.

        The group name. Must be unique for a given version.  # noqa: E501

        :param name: The name of this Group.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501
        if (self._configuration.client_side_validation and
                name is not None and len(name) < 1):
            raise ValueError("Invalid value for `name`, length must be greater than or equal to `1`")  # noqa: E501

        self._name = name

    @property
    def version_id(self):
        """Gets the version_id of this Group.  # noqa: E501

        The version id to which the group belongs to.  # noqa: E501

        :return: The version_id of this Group.  # noqa: E501
        :rtype: str
        """
        return self._version_id

    @version_id.setter
    def version_id(self, version_id):
        """Sets the version_id of this Group.

        The version id to which the group belongs to.  # noqa: E501

        :param version_id: The version_id of this Group.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and version_id is None:
            raise ValueError("Invalid value for `version_id`, must not be `None`")  # noqa: E501

        self._version_id = version_id

    @property
    def parent_group_id(self):
        """Gets the parent_group_id of this Group.  # noqa: E501

        The parent group id to which the group belongs to.  Leave the property to Guid.Empty (00000000-0000-0000-0000-000000000000) if the group doesn't have parent.  # noqa: E501

        :return: The parent_group_id of this Group.  # noqa: E501
        :rtype: str
        """
        return self._parent_group_id

    @parent_group_id.setter
    def parent_group_id(self, parent_group_id):
        """Sets the parent_group_id of this Group.

        The parent group id to which the group belongs to.  Leave the property to Guid.Empty (00000000-0000-0000-0000-000000000000) if the group doesn't have parent.  # noqa: E501

        :param parent_group_id: The parent_group_id of this Group.  # noqa: E501
        :type: str
        """

        self._parent_group_id = parent_group_id

    @property
    def last_update_date_utc(self):
        """Gets the last_update_date_utc of this Group.  # noqa: E501

        The last utc date time when the properties of the group have been updated.  This field will be automatically updated from the server side each time you update the object.  # noqa: E501

        :return: The last_update_date_utc of this Group.  # noqa: E501
        :rtype: datetime
        """
        return self._last_update_date_utc

    @last_update_date_utc.setter
    def last_update_date_utc(self, last_update_date_utc):
        """Sets the last_update_date_utc of this Group.

        The last utc date time when the properties of the group have been updated.  This field will be automatically updated from the server side each time you update the object.  # noqa: E501

        :param last_update_date_utc: The last_update_date_utc of this Group.  # noqa: E501
        :type: datetime
        """

        self._last_update_date_utc = last_update_date_utc

    @property
    def last_update_user(self):
        """Gets the last_update_user of this Group.  # noqa: E501

        The name of the last user having updated the group.  This field will be automatically updated from the server side each time you update the object.  # noqa: E501

        :return: The last_update_user of this Group.  # noqa: E501
        :rtype: str
        """
        return self._last_update_user

    @last_update_user.setter
    def last_update_user(self, last_update_user):
        """Sets the last_update_user of this Group.

        The name of the last user having updated the group.  This field will be automatically updated from the server side each time you update the object.  # noqa: E501

        :param last_update_user: The last_update_user of this Group.  # noqa: E501
        :type: str
        """

        self._last_update_user = last_update_user

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Group, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Group):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Group):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Trackside Software TeamDB API v2.0

    This API enables you to access TeamDB data  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@trackside.fr
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from teamdbapi.configuration import Configuration


class Target(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'name': 'str',
        'description': 'str',
        'file_format': 'str',
        'auto_generate_assembly': 'bool',
        'auto_generate_assembly_version_id': 'str',
        'revision_merge_comment_mandatory': 'bool',
        'assembly_name_suffix': 'str'
    }

    attribute_map = {
        'id': 'Id',
        'name': 'Name',
        'description': 'Description',
        'file_format': 'FileFormat',
        'auto_generate_assembly': 'AutoGenerateAssembly',
        'auto_generate_assembly_version_id': 'AutoGenerateAssemblyVersionId',
        'revision_merge_comment_mandatory': 'RevisionMergeCommentMandatory',
        'assembly_name_suffix': 'AssemblyNameSuffix'
    }

    def __init__(self, id=None, name=None, description=None, file_format=None, auto_generate_assembly=None, auto_generate_assembly_version_id=None, revision_merge_comment_mandatory=None, assembly_name_suffix=None, _configuration=None):  # noqa: E501
        """Target - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._id = None
        self._name = None
        self._description = None
        self._file_format = None
        self._auto_generate_assembly = None
        self._auto_generate_assembly_version_id = None
        self._revision_merge_comment_mandatory = None
        self._assembly_name_suffix = None
        self.discriminator = None

        self.id = id
        self.name = name
        if description is not None:
            self.description = description
        self.file_format = file_format
        if auto_generate_assembly is not None:
            self.auto_generate_assembly = auto_generate_assembly
        if auto_generate_assembly_version_id is not None:
            self.auto_generate_assembly_version_id = auto_generate_assembly_version_id
        if revision_merge_comment_mandatory is not None:
            self.revision_merge_comment_mandatory = revision_merge_comment_mandatory
        if assembly_name_suffix is not None:
            self.assembly_name_suffix = assembly_name_suffix

    @property
    def id(self):
        """Gets the id of this Target.  # noqa: E501

        The unique target id.  Set the Id to Guid.Empty (00000000-0000-0000-0000-000000000000) if you want to create a new target.  # noqa: E501

        :return: The id of this Target.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Target.

        The unique target id.  Set the Id to Guid.Empty (00000000-0000-0000-0000-000000000000) if you want to create a new target.  # noqa: E501

        :param id: The id of this Target.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def name(self):
        """Gets the name of this Target.  # noqa: E501

        The target unique name  # noqa: E501

        :return: The name of this Target.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Target.

        The target unique name  # noqa: E501

        :param name: The name of this Target.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501
        if (self._configuration.client_side_validation and
                name is not None and len(name) < 1):
            raise ValueError("Invalid value for `name`, length must be greater than or equal to `1`")  # noqa: E501

        self._name = name

    @property
    def description(self):
        """Gets the description of this Target.  # noqa: E501

        The target description  # noqa: E501

        :return: The description of this Target.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this Target.

        The target description  # noqa: E501

        :param description: The description of this Target.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def file_format(self):
        """Gets the file_format of this Target.  # noqa: E501

        The file format used to create the target versions.  Simu = 1, M = 2, Dcm = 3, Clx = 4  # noqa: E501

        :return: The file_format of this Target.  # noqa: E501
        :rtype: str
        """
        return self._file_format

    @file_format.setter
    def file_format(self, file_format):
        """Sets the file_format of this Target.

        The file format used to create the target versions.  Simu = 1, M = 2, Dcm = 3, Clx = 4  # noqa: E501

        :param file_format: The file_format of this Target.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and file_format is None:
            raise ValueError("Invalid value for `file_format`, must not be `None`")  # noqa: E501
        allowed_values = ["Simu", "M", "Dcm", "Clx"]  # noqa: E501
        if (self._configuration.client_side_validation and
                file_format not in allowed_values):
            raise ValueError(
                "Invalid value for `file_format` ({0}), must be one of {1}"  # noqa: E501
                .format(file_format, allowed_values)
            )

        self._file_format = file_format

    @property
    def auto_generate_assembly(self):
        """Gets the auto_generate_assembly of this Target.  # noqa: E501

        True if we want to automatically generate assemblies when new Runs are created  # noqa: E501

        :return: The auto_generate_assembly of this Target.  # noqa: E501
        :rtype: bool
        """
        return self._auto_generate_assembly

    @auto_generate_assembly.setter
    def auto_generate_assembly(self, auto_generate_assembly):
        """Sets the auto_generate_assembly of this Target.

        True if we want to automatically generate assemblies when new Runs are created  # noqa: E501

        :param auto_generate_assembly: The auto_generate_assembly of this Target.  # noqa: E501
        :type: bool
        """

        self._auto_generate_assembly = auto_generate_assembly

    @property
    def auto_generate_assembly_version_id(self):
        """Gets the auto_generate_assembly_version_id of this Target.  # noqa: E501

        The version unqiue Id used as reference to create the assemblies when AutoGenerateAssembly is true.  It is also used to display the current version in the drop down list.  # noqa: E501

        :return: The auto_generate_assembly_version_id of this Target.  # noqa: E501
        :rtype: str
        """
        return self._auto_generate_assembly_version_id

    @auto_generate_assembly_version_id.setter
    def auto_generate_assembly_version_id(self, auto_generate_assembly_version_id):
        """Sets the auto_generate_assembly_version_id of this Target.

        The version unqiue Id used as reference to create the assemblies when AutoGenerateAssembly is true.  It is also used to display the current version in the drop down list.  # noqa: E501

        :param auto_generate_assembly_version_id: The auto_generate_assembly_version_id of this Target.  # noqa: E501
        :type: str
        """

        self._auto_generate_assembly_version_id = auto_generate_assembly_version_id

    @property
    def revision_merge_comment_mandatory(self):
        """Gets the revision_merge_comment_mandatory of this Target.  # noqa: E501

        True if you want to set comments mandatory when you merge revisions after a comparison.  # noqa: E501

        :return: The revision_merge_comment_mandatory of this Target.  # noqa: E501
        :rtype: bool
        """
        return self._revision_merge_comment_mandatory

    @revision_merge_comment_mandatory.setter
    def revision_merge_comment_mandatory(self, revision_merge_comment_mandatory):
        """Sets the revision_merge_comment_mandatory of this Target.

        True if you want to set comments mandatory when you merge revisions after a comparison.  # noqa: E501

        :param revision_merge_comment_mandatory: The revision_merge_comment_mandatory of this Target.  # noqa: E501
        :type: bool
        """

        self._revision_merge_comment_mandatory = revision_merge_comment_mandatory

    @property
    def assembly_name_suffix(self):
        """Gets the assembly_name_suffix of this Target.  # noqa: E501

        The suffix name automatically applyed to the assemblies name created by Teamdb.  Must not contains _. Only contains zero or many letters and end with at least one 0.  # noqa: E501

        :return: The assembly_name_suffix of this Target.  # noqa: E501
        :rtype: str
        """
        return self._assembly_name_suffix

    @assembly_name_suffix.setter
    def assembly_name_suffix(self, assembly_name_suffix):
        """Sets the assembly_name_suffix of this Target.

        The suffix name automatically applyed to the assemblies name created by Teamdb.  Must not contains _. Only contains zero or many letters and end with at least one 0.  # noqa: E501

        :param assembly_name_suffix: The assembly_name_suffix of this Target.  # noqa: E501
        :type: str
        """

        self._assembly_name_suffix = assembly_name_suffix

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Target, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Target):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Target):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Trackside Software TeamDB API v2.0

    This API enables you to access TeamDB data  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@trackside.fr
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from teamdbapi.configuration import Configuration


class ImportParametersArgs(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'version_id': 'str',
        'file_paths': 'list[str]',
        'revision_name': 'str',
        'revision_maturity': 'int',
        'revision_comment': 'str',
        'use_revision_names_from_assembly': 'bool',
        'revision_names_from_assembly_id': 'str',
        'use_revision_comments_from_assembly': 'bool',
        'create_assembly': 'bool',
        'created_assembly_name': 'str',
        'created_group_revisions_like_specified_version': 'bool',
        'ignore_load_file_warning': 'bool'
    }

    attribute_map = {
        'version_id': 'VersionId',
        'file_paths': 'FilePaths',
        'revision_name': 'RevisionName',
        'revision_maturity': 'RevisionMaturity',
        'revision_comment': 'RevisionComment',
        'use_revision_names_from_assembly': 'UseRevisionNamesFromAssembly',
        'revision_names_from_assembly_id': 'RevisionNamesFromAssemblyId',
        'use_revision_comments_from_assembly': 'UseRevisionCommentsFromAssembly',
        'create_assembly': 'CreateAssembly',
        'created_assembly_name': 'CreatedAssemblyName',
        'created_group_revisions_like_specified_version': 'CreatedGroupRevisionsLikeSpecifiedVersion',
        'ignore_load_file_warning': 'IgnoreLoadFileWarning'
    }

    def __init__(self, version_id=None, file_paths=None, revision_name=None, revision_maturity=None, revision_comment=None, use_revision_names_from_assembly=None, revision_names_from_assembly_id=None, use_revision_comments_from_assembly=None, create_assembly=None, created_assembly_name=None, created_group_revisions_like_specified_version=None, ignore_load_file_warning=None, _configuration=None):  # noqa: E501
        """ImportParametersArgs - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._version_id = None
        self._file_paths = None
        self._revision_name = None
        self._revision_maturity = None
        self._revision_comment = None
        self._use_revision_names_from_assembly = None
        self._revision_names_from_assembly_id = None
        self._use_revision_comments_from_assembly = None
        self._create_assembly = None
        self._created_assembly_name = None
        self._created_group_revisions_like_specified_version = None
        self._ignore_load_file_warning = None
        self.discriminator = None

        self.version_id = version_id
        self.file_paths = file_paths
        self.revision_name = revision_name
        if revision_maturity is not None:
            self.revision_maturity = revision_maturity
        if revision_comment is not None:
            self.revision_comment = revision_comment
        self.use_revision_names_from_assembly = use_revision_names_from_assembly
        if revision_names_from_assembly_id is not None:
            self.revision_names_from_assembly_id = revision_names_from_assembly_id
        if use_revision_comments_from_assembly is not None:
            self.use_revision_comments_from_assembly = use_revision_comments_from_assembly
        self.create_assembly = create_assembly
        if created_assembly_name is not None:
            self.created_assembly_name = created_assembly_name
        self.created_group_revisions_like_specified_version = created_group_revisions_like_specified_version
        self.ignore_load_file_warning = ignore_load_file_warning

    @property
    def version_id(self):
        """Gets the version_id of this ImportParametersArgs.  # noqa: E501

        The version unique identifier to which import the data  # noqa: E501

        :return: The version_id of this ImportParametersArgs.  # noqa: E501
        :rtype: str
        """
        return self._version_id

    @version_id.setter
    def version_id(self, version_id):
        """Sets the version_id of this ImportParametersArgs.

        The version unique identifier to which import the data  # noqa: E501

        :param version_id: The version_id of this ImportParametersArgs.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and version_id is None:
            raise ValueError("Invalid value for `version_id`, must not be `None`")  # noqa: E501

        self._version_id = version_id

    @property
    def file_paths(self):
        """Gets the file_paths of this ImportParametersArgs.  # noqa: E501

        The paths to the files to import  # noqa: E501

        :return: The file_paths of this ImportParametersArgs.  # noqa: E501
        :rtype: list[str]
        """
        return self._file_paths

    @file_paths.setter
    def file_paths(self, file_paths):
        """Sets the file_paths of this ImportParametersArgs.

        The paths to the files to import  # noqa: E501

        :param file_paths: The file_paths of this ImportParametersArgs.  # noqa: E501
        :type: list[str]
        """
        if self._configuration.client_side_validation and file_paths is None:
            raise ValueError("Invalid value for `file_paths`, must not be `None`")  # noqa: E501

        self._file_paths = file_paths

    @property
    def revision_name(self):
        """Gets the revision_name of this ImportParametersArgs.  # noqa: E501

        The revision name used to create new revisions  # noqa: E501

        :return: The revision_name of this ImportParametersArgs.  # noqa: E501
        :rtype: str
        """
        return self._revision_name

    @revision_name.setter
    def revision_name(self, revision_name):
        """Sets the revision_name of this ImportParametersArgs.

        The revision name used to create new revisions  # noqa: E501

        :param revision_name: The revision_name of this ImportParametersArgs.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and revision_name is None:
            raise ValueError("Invalid value for `revision_name`, must not be `None`")  # noqa: E501
        if (self._configuration.client_side_validation and
                revision_name is not None and len(revision_name) < 1):
            raise ValueError("Invalid value for `revision_name`, length must be greater than or equal to `1`")  # noqa: E501

        self._revision_name = revision_name

    @property
    def revision_maturity(self):
        """Gets the revision_maturity of this ImportParametersArgs.  # noqa: E501

        The revision maturity used when new revisions are created or null is not needed  # noqa: E501

        :return: The revision_maturity of this ImportParametersArgs.  # noqa: E501
        :rtype: int
        """
        return self._revision_maturity

    @revision_maturity.setter
    def revision_maturity(self, revision_maturity):
        """Sets the revision_maturity of this ImportParametersArgs.

        The revision maturity used when new revisions are created or null is not needed  # noqa: E501

        :param revision_maturity: The revision_maturity of this ImportParametersArgs.  # noqa: E501
        :type: int
        """
        if (self._configuration.client_side_validation and
                revision_maturity is not None and revision_maturity > 100):  # noqa: E501
            raise ValueError("Invalid value for `revision_maturity`, must be a value less than or equal to `100`")  # noqa: E501
        if (self._configuration.client_side_validation and
                revision_maturity is not None and revision_maturity < 0):  # noqa: E501
            raise ValueError("Invalid value for `revision_maturity`, must be a value greater than or equal to `0`")  # noqa: E501

        self._revision_maturity = revision_maturity

    @property
    def revision_comment(self):
        """Gets the revision_comment of this ImportParametersArgs.  # noqa: E501

        The revision comment used when new revisions are created or null is not needed  # noqa: E501

        :return: The revision_comment of this ImportParametersArgs.  # noqa: E501
        :rtype: str
        """
        return self._revision_comment

    @revision_comment.setter
    def revision_comment(self, revision_comment):
        """Sets the revision_comment of this ImportParametersArgs.

        The revision comment used when new revisions are created or null is not needed  # noqa: E501

        :param revision_comment: The revision_comment of this ImportParametersArgs.  # noqa: E501
        :type: str
        """

        self._revision_comment = revision_comment

    @property
    def use_revision_names_from_assembly(self):
        """Gets the use_revision_names_from_assembly of this ImportParametersArgs.  # noqa: E501

        Specify if the revision names used to create new revisions are generated from the assembly specified by RevisionNamesFromAssemblyId  # noqa: E501

        :return: The use_revision_names_from_assembly of this ImportParametersArgs.  # noqa: E501
        :rtype: bool
        """
        return self._use_revision_names_from_assembly

    @use_revision_names_from_assembly.setter
    def use_revision_names_from_assembly(self, use_revision_names_from_assembly):
        """Sets the use_revision_names_from_assembly of this ImportParametersArgs.

        Specify if the revision names used to create new revisions are generated from the assembly specified by RevisionNamesFromAssemblyId  # noqa: E501

        :param use_revision_names_from_assembly: The use_revision_names_from_assembly of this ImportParametersArgs.  # noqa: E501
        :type: bool
        """
        if self._configuration.client_side_validation and use_revision_names_from_assembly is None:
            raise ValueError("Invalid value for `use_revision_names_from_assembly`, must not be `None`")  # noqa: E501

        self._use_revision_names_from_assembly = use_revision_names_from_assembly

    @property
    def revision_names_from_assembly_id(self):
        """Gets the revision_names_from_assembly_id of this ImportParametersArgs.  # noqa: E501

        The assembly unique identifier used to generate the revision names when UseRevisionNamesFromAssembly is true  # noqa: E501

        :return: The revision_names_from_assembly_id of this ImportParametersArgs.  # noqa: E501
        :rtype: str
        """
        return self._revision_names_from_assembly_id

    @revision_names_from_assembly_id.setter
    def revision_names_from_assembly_id(self, revision_names_from_assembly_id):
        """Sets the revision_names_from_assembly_id of this ImportParametersArgs.

        The assembly unique identifier used to generate the revision names when UseRevisionNamesFromAssembly is true  # noqa: E501

        :param revision_names_from_assembly_id: The revision_names_from_assembly_id of this ImportParametersArgs.  # noqa: E501
        :type: str
        """

        self._revision_names_from_assembly_id = revision_names_from_assembly_id

    @property
    def use_revision_comments_from_assembly(self):
        """Gets the use_revision_comments_from_assembly of this ImportParametersArgs.  # noqa: E501

        Specify if the revision comments are copied from the assembly defined by RevisionNamesFromAssemblyId  # noqa: E501

        :return: The use_revision_comments_from_assembly of this ImportParametersArgs.  # noqa: E501
        :rtype: bool
        """
        return self._use_revision_comments_from_assembly

    @use_revision_comments_from_assembly.setter
    def use_revision_comments_from_assembly(self, use_revision_comments_from_assembly):
        """Sets the use_revision_comments_from_assembly of this ImportParametersArgs.

        Specify if the revision comments are copied from the assembly defined by RevisionNamesFromAssemblyId  # noqa: E501

        :param use_revision_comments_from_assembly: The use_revision_comments_from_assembly of this ImportParametersArgs.  # noqa: E501
        :type: bool
        """

        self._use_revision_comments_from_assembly = use_revision_comments_from_assembly

    @property
    def create_assembly(self):
        """Gets the create_assembly of this ImportParametersArgs.  # noqa: E501

        Specify if a new assembly must be created during the import  # noqa: E501

        :return: The create_assembly of this ImportParametersArgs.  # noqa: E501
        :rtype: bool
        """
        return self._create_assembly

    @create_assembly.setter
    def create_assembly(self, create_assembly):
        """Sets the create_assembly of this ImportParametersArgs.

        Specify if a new assembly must be created during the import  # noqa: E501

        :param create_assembly: The create_assembly of this ImportParametersArgs.  # noqa: E501
        :type: bool
        """
        if self._configuration.client_side_validation and create_assembly is None:
            raise ValueError("Invalid value for `create_assembly`, must not be `None`")  # noqa: E501

        self._create_assembly = create_assembly

    @property
    def created_assembly_name(self):
        """Gets the created_assembly_name of this ImportParametersArgs.  # noqa: E501

        The name used to create the new assembly when CreateAssembly is true  # noqa: E501

        :return: The created_assembly_name of this ImportParametersArgs.  # noqa: E501
        :rtype: str
        """
        return self._created_assembly_name

    @created_assembly_name.setter
    def created_assembly_name(self, created_assembly_name):
        """Sets the created_assembly_name of this ImportParametersArgs.

        The name used to create the new assembly when CreateAssembly is true  # noqa: E501

        :param created_assembly_name: The created_assembly_name of this ImportParametersArgs.  # noqa: E501
        :type: str
        """

        self._created_assembly_name = created_assembly_name

    @property
    def created_group_revisions_like_specified_version(self):
        """Gets the created_group_revisions_like_specified_version of this ImportParametersArgs.  # noqa: E501

        Specify if new group revision must be created automatically like those existing in the version.  # noqa: E501

        :return: The created_group_revisions_like_specified_version of this ImportParametersArgs.  # noqa: E501
        :rtype: bool
        """
        return self._created_group_revisions_like_specified_version

    @created_group_revisions_like_specified_version.setter
    def created_group_revisions_like_specified_version(self, created_group_revisions_like_specified_version):
        """Sets the created_group_revisions_like_specified_version of this ImportParametersArgs.

        Specify if new group revision must be created automatically like those existing in the version.  # noqa: E501

        :param created_group_revisions_like_specified_version: The created_group_revisions_like_specified_version of this ImportParametersArgs.  # noqa: E501
        :type: bool
        """
        if self._configuration.client_side_validation and created_group_revisions_like_specified_version is None:
            raise ValueError("Invalid value for `created_group_revisions_like_specified_version`, must not be `None`")  # noqa: E501

        self._created_group_revisions_like_specified_version = created_group_revisions_like_specified_version

    @property
    def ignore_load_file_warning(self):
        """Gets the ignore_load_file_warning of this ImportParametersArgs.  # noqa: E501

        True to ignore the warnings detected before importing the file and continue the import process if they are not blocking.  False to stop the import if a warning is detected.  # noqa: E501

        :return: The ignore_load_file_warning of this ImportParametersArgs.  # noqa: E501
        :rtype: bool
        """
        return self._ignore_load_file_warning

    @ignore_load_file_warning.setter
    def ignore_load_file_warning(self, ignore_load_file_warning):
        """Sets the ignore_load_file_warning of this ImportParametersArgs.

        True to ignore the warnings detected before importing the file and continue the import process if they are not blocking.  False to stop the import if a warning is detected.  # noqa: E501

        :param ignore_load_file_warning: The ignore_load_file_warning of this ImportParametersArgs.  # noqa: E501
        :type: bool
        """
        if self._configuration.client_side_validation and ignore_load_file_warning is None:
            raise ValueError("Invalid value for `ignore_load_file_warning`, must not be `None`")  # noqa: E501

        self._ignore_load_file_warning = ignore_load_file_warning

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ImportParametersArgs, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ImportParametersArgs):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ImportParametersArgs):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Trackside Software TeamDB API v2.0

    This API enables you to access TeamDB data  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@trackside.fr
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from teamdbapi.configuration import Configuration


class CompareResult(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'reference': 'str',
        'data_axe_x': 'list[float]',
        'data_axe_y': 'list[float]',
        'data_axe_z': 'list[float]',
        'data': 'list[object]',
        'revision_name': 'str'
    }

    attribute_map = {
        'reference': 'Reference',
        'data_axe_x': 'DataAxeX',
        'data_axe_y': 'DataAxeY',
        'data_axe_z': 'DataAxeZ',
        'data': 'Data',
        'revision_name': 'RevisionName'
    }

    def __init__(self, reference=None, data_axe_x=None, data_axe_y=None, data_axe_z=None, data=None, revision_name=None, _configuration=None):  # noqa: E501
        """CompareResult - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._reference = None
        self._data_axe_x = None
        self._data_axe_y = None
        self._data_axe_z = None
        self._data = None
        self._revision_name = None
        self.discriminator = None

        if reference is not None:
            self.reference = reference
        if data_axe_x is not None:
            self.data_axe_x = data_axe_x
        if data_axe_y is not None:
            self.data_axe_y = data_axe_y
        if data_axe_z is not None:
            self.data_axe_z = data_axe_z
        if data is not None:
            self.data = data
        if revision_name is not None:
            self.revision_name = revision_name

    @property
    def reference(self):
        """Gets the reference of this CompareResult.  # noqa: E501

        Parameter reference  # noqa: E501

        :return: The reference of this CompareResult.  # noqa: E501
        :rtype: str
        """
        return self._reference

    @reference.setter
    def reference(self, reference):
        """Sets the reference of this CompareResult.

        Parameter reference  # noqa: E501

        :param reference: The reference of this CompareResult.  # noqa: E501
        :type: str
        """

        self._reference = reference

    @property
    def data_axe_x(self):
        """Gets the data_axe_x of this CompareResult.  # noqa: E501

        Data axe X  # noqa: E501

        :return: The data_axe_x of this CompareResult.  # noqa: E501
        :rtype: list[float]
        """
        return self._data_axe_x

    @data_axe_x.setter
    def data_axe_x(self, data_axe_x):
        """Sets the data_axe_x of this CompareResult.

        Data axe X  # noqa: E501

        :param data_axe_x: The data_axe_x of this CompareResult.  # noqa: E501
        :type: list[float]
        """

        self._data_axe_x = data_axe_x

    @property
    def data_axe_y(self):
        """Gets the data_axe_y of this CompareResult.  # noqa: E501

        Data axe Y  # noqa: E501

        :return: The data_axe_y of this CompareResult.  # noqa: E501
        :rtype: list[float]
        """
        return self._data_axe_y

    @data_axe_y.setter
    def data_axe_y(self, data_axe_y):
        """Sets the data_axe_y of this CompareResult.

        Data axe Y  # noqa: E501

        :param data_axe_y: The data_axe_y of this CompareResult.  # noqa: E501
        :type: list[float]
        """

        self._data_axe_y = data_axe_y

    @property
    def data_axe_z(self):
        """Gets the data_axe_z of this CompareResult.  # noqa: E501

        Data axe Z  # noqa: E501

        :return: The data_axe_z of this CompareResult.  # noqa: E501
        :rtype: list[float]
        """
        return self._data_axe_z

    @data_axe_z.setter
    def data_axe_z(self, data_axe_z):
        """Sets the data_axe_z of this CompareResult.

        Data axe Z  # noqa: E501

        :param data_axe_z: The data_axe_z of this CompareResult.  # noqa: E501
        :type: list[float]
        """

        self._data_axe_z = data_axe_z

    @property
    def data(self):
        """Gets the data of this CompareResult.  # noqa: E501

        Parameter data  # noqa: E501

        :return: The data of this CompareResult.  # noqa: E501
        :rtype: list[object]
        """
        return self._data

    @data.setter
    def data(self, data):
        """Sets the data of this CompareResult.

        Parameter data  # noqa: E501

        :param data: The data of this CompareResult.  # noqa: E501
        :type: list[object]
        """

        self._data = data

    @property
    def revision_name(self):
        """Gets the revision_name of this CompareResult.  # noqa: E501

        Revision name  # noqa: E501

        :return: The revision_name of this CompareResult.  # noqa: E501
        :rtype: str
        """
        return self._revision_name

    @revision_name.setter
    def revision_name(self, revision_name):
        """Sets the revision_name of this CompareResult.

        Revision name  # noqa: E501

        :param revision_name: The revision_name of this CompareResult.  # noqa: E501
        :type: str
        """

        self._revision_name = revision_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CompareResult, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CompareResult):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CompareResult):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Trackside Software TeamDB API v2.0

    This API enables you to access TeamDB data  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@trackside.fr
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from teamdbapi.configuration import Configuration


class ModelField(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'name': 'str',
        'description': 'str',
        'type_of_model_field': 'str',
        'type_of_value': 'str',
        'type_of_value_source': 'str',
        'source_path': 'str',
        'source_tag': 'str',
        'followed': 'bool',
        'duplicate': 'bool',
        'is_computed_field': 'bool',
        'calcul_type': 'str',
        'target_model_field_id': 'str',
        'export_value_name': 'str',
        'export_constant_file_name': 'str',
        'list_id': 'str',
        'item_list_can_be_add': 'bool',
        'revision_selector_param': 'list[CoupleGuidText]',
        'revision_selector_show_only_group_rev': 'bool',
        'revision_editor_display_format': 'str',
        'script_content': 'str',
        'use_invalid_lap_for_calculation': 'bool',
        'tags': 'str',
        'default_value': 'object'
    }

    attribute_map = {
        'id': 'Id',
        'name': 'Name',
        'description': 'Description',
        'type_of_model_field': 'TypeOfModelField',
        'type_of_value': 'TypeOfValue',
        'type_of_value_source': 'TypeOfValueSource',
        'source_path': 'SourcePath',
        'source_tag': 'SourceTag',
        'followed': 'Followed',
        'duplicate': 'Duplicate',
        'is_computed_field': 'IsComputedField',
        'calcul_type': 'CalculType',
        'target_model_field_id': 'TargetModelFieldId',
        'export_value_name': 'ExportValueName',
        'export_constant_file_name': 'ExportConstantFileName',
        'list_id': 'ListId',
        'item_list_can_be_add': 'ItemListCanBeAdd',
        'revision_selector_param': 'RevisionSelectorParam',
        'revision_selector_show_only_group_rev': 'RevisionSelectorShowOnlyGroupRev',
        'revision_editor_display_format': 'RevisionEditorDisplayFormat',
        'script_content': 'ScriptContent',
        'use_invalid_lap_for_calculation': 'UseInvalidLapForCalculation',
        'tags': 'Tags',
        'default_value': 'DefaultValue'
    }

    def __init__(self, id=None, name=None, description=None, type_of_model_field=None, type_of_value=None, type_of_value_source=None, source_path=None, source_tag=None, followed=None, duplicate=None, is_computed_field=None, calcul_type=None, target_model_field_id=None, export_value_name=None, export_constant_file_name=None, list_id=None, item_list_can_be_add=None, revision_selector_param=None, revision_selector_show_only_group_rev=None, revision_editor_display_format=None, script_content=None, use_invalid_lap_for_calculation=None, tags=None, default_value=None, _configuration=None):  # noqa: E501
        """ModelField - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._id = None
        self._name = None
        self._description = None
        self._type_of_model_field = None
        self._type_of_value = None
        self._type_of_value_source = None
        self._source_path = None
        self._source_tag = None
        self._followed = None
        self._duplicate = None
        self._is_computed_field = None
        self._calcul_type = None
        self._target_model_field_id = None
        self._export_value_name = None
        self._export_constant_file_name = None
        self._list_id = None
        self._item_list_can_be_add = None
        self._revision_selector_param = None
        self._revision_selector_show_only_group_rev = None
        self._revision_editor_display_format = None
        self._script_content = None
        self._use_invalid_lap_for_calculation = None
        self._tags = None
        self._default_value = None
        self.discriminator = None

        self.id = id
        self.name = name
        if description is not None:
            self.description = description
        self.type_of_model_field = type_of_model_field
        self.type_of_value = type_of_value
        if type_of_value_source is not None:
            self.type_of_value_source = type_of_value_source
        if source_path is not None:
            self.source_path = source_path
        if source_tag is not None:
            self.source_tag = source_tag
        if followed is not None:
            self.followed = followed
        if duplicate is not None:
            self.duplicate = duplicate
        if is_computed_field is not None:
            self.is_computed_field = is_computed_field
        if calcul_type is not None:
            self.calcul_type = calcul_type
        if target_model_field_id is not None:
            self.target_model_field_id = target_model_field_id
        if export_value_name is not None:
            self.export_value_name = export_value_name
        if export_constant_file_name is not None:
            self.export_constant_file_name = export_constant_file_name
        if list_id is not None:
            self.list_id = list_id
        if item_list_can_be_add is not None:
            self.item_list_can_be_add = item_list_can_be_add
        if revision_selector_param is not None:
            self.revision_selector_param = revision_selector_param
        if revision_selector_show_only_group_rev is not None:
            self.revision_selector_show_only_group_rev = revision_selector_show_only_group_rev
        if revision_editor_display_format is not None:
            self.revision_editor_display_format = revision_editor_display_format
        if script_content is not None:
            self.script_content = script_content
        if use_invalid_lap_for_calculation is not None:
            self.use_invalid_lap_for_calculation = use_invalid_lap_for_calculation
        if tags is not None:
            self.tags = tags
        if default_value is not None:
            self.default_value = default_value

    @property
    def id(self):
        """Gets the id of this ModelField.  # noqa: E501

        The unique model field Id.  Set the Id to Guid.Empty (00000000-0000-0000-0000-000000000000) if you want to create a new Model Field.  # noqa: E501

        :return: The id of this ModelField.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ModelField.

        The unique model field Id.  Set the Id to Guid.Empty (00000000-0000-0000-0000-000000000000) if you want to create a new Model Field.  # noqa: E501

        :param id: The id of this ModelField.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def name(self):
        """Gets the name of this ModelField.  # noqa: E501

        The model field name  # noqa: E501

        :return: The name of this ModelField.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ModelField.

        The model field name  # noqa: E501

        :param name: The name of this ModelField.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501
        if (self._configuration.client_side_validation and
                name is not None and len(name) < 1):
            raise ValueError("Invalid value for `name`, length must be greater than or equal to `1`")  # noqa: E501

        self._name = name

    @property
    def description(self):
        """Gets the description of this ModelField.  # noqa: E501

        The model field description  # noqa: E501

        :return: The description of this ModelField.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this ModelField.

        The model field description  # noqa: E501

        :param description: The description of this ModelField.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def type_of_model_field(self):
        """Gets the type_of_model_field of this ModelField.  # noqa: E501

        The model field type.  # noqa: E501

        :return: The type_of_model_field of this ModelField.  # noqa: E501
        :rtype: str
        """
        return self._type_of_model_field

    @type_of_model_field.setter
    def type_of_model_field(self, type_of_model_field):
        """Sets the type_of_model_field of this ModelField.

        The model field type.  # noqa: E501

        :param type_of_model_field: The type_of_model_field of this ModelField.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and type_of_model_field is None:
            raise ValueError("Invalid value for `type_of_model_field`, must not be `None`")  # noqa: E501
        allowed_values = ["Event", "Session", "Run", "Lap", "Car"]  # noqa: E501
        if (self._configuration.client_side_validation and
                type_of_model_field not in allowed_values):
            raise ValueError(
                "Invalid value for `type_of_model_field` ({0}), must be one of {1}"  # noqa: E501
                .format(type_of_model_field, allowed_values)
            )

        self._type_of_model_field = type_of_model_field

    @property
    def type_of_value(self):
        """Gets the type_of_value of this ModelField.  # noqa: E501

        The model field value type.  # noqa: E501

        :return: The type_of_value of this ModelField.  # noqa: E501
        :rtype: str
        """
        return self._type_of_value

    @type_of_value.setter
    def type_of_value(self, type_of_value):
        """Sets the type_of_value of this ModelField.

        The model field value type.  # noqa: E501

        :param type_of_value: The type_of_value of this ModelField.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and type_of_value is None:
            raise ValueError("Invalid value for `type_of_value`, must not be `None`")  # noqa: E501
        allowed_values = ["Double", "String", "Bool", "TimeSpan", "DateTime", "TeamDBList", "Int", "Rtf", "StringMultiline", "TeamDBGrid", "Image", "File", "RevisionSelector", "RevisionEditor", "HyperlinkTextBox", "HyperlinkIntTextBox", "LifingRunMountingDiff", "Files", "Text"]  # noqa: E501
        if (self._configuration.client_side_validation and
                type_of_value not in allowed_values):
            raise ValueError(
                "Invalid value for `type_of_value` ({0}), must be one of {1}"  # noqa: E501
                .format(type_of_value, allowed_values)
            )

        self._type_of_value = type_of_value

    @property
    def type_of_value_source(self):
        """Gets the type_of_value_source of this ModelField.  # noqa: E501

        The model field value source.  # noqa: E501

        :return: The type_of_value_source of this ModelField.  # noqa: E501
        :rtype: str
        """
        return self._type_of_value_source

    @type_of_value_source.setter
    def type_of_value_source(self, type_of_value_source):
        """Sets the type_of_value_source of this ModelField.

        The model field value source.  # noqa: E501

        :param type_of_value_source: The type_of_value_source of this ModelField.  # noqa: E501
        :type: str
        """
        allowed_values = ["Manual", "LapReport", "Excel", "Spc", "Server"]  # noqa: E501
        if (self._configuration.client_side_validation and
                type_of_value_source not in allowed_values):
            raise ValueError(
                "Invalid value for `type_of_value_source` ({0}), must be one of {1}"  # noqa: E501
                .format(type_of_value_source, allowed_values)
            )

        self._type_of_value_source = type_of_value_source

    @property
    def source_path(self):
        """Gets the source_path of this ModelField.  # noqa: E501

        The model field value source path.  # noqa: E501

        :return: The source_path of this ModelField.  # noqa: E501
        :rtype: str
        """
        return self._source_path

    @source_path.setter
    def source_path(self, source_path):
        """Sets the source_path of this ModelField.

        The model field value source path.  # noqa: E501

        :param source_path: The source_path of this ModelField.  # noqa: E501
        :type: str
        """

        self._source_path = source_path

    @property
    def source_tag(self):
        """Gets the source_tag of this ModelField.  # noqa: E501

        The location of informations into the value source.  # noqa: E501

        :return: The source_tag of this ModelField.  # noqa: E501
        :rtype: str
        """
        return self._source_tag

    @source_tag.setter
    def source_tag(self, source_tag):
        """Sets the source_tag of this ModelField.

        The location of informations into the value source.  # noqa: E501

        :param source_tag: The source_tag of this ModelField.  # noqa: E501
        :type: str
        """

        self._source_tag = source_tag

    @property
    def followed(self):
        """Gets the followed of this ModelField.  # noqa: E501

        Set to True to automatically use a value when the field is created.  # noqa: E501

        :return: The followed of this ModelField.  # noqa: E501
        :rtype: bool
        """
        return self._followed

    @followed.setter
    def followed(self, followed):
        """Sets the followed of this ModelField.

        Set to True to automatically use a value when the field is created.  # noqa: E501

        :param followed: The followed of this ModelField.  # noqa: E501
        :type: bool
        """

        self._followed = followed

    @property
    def duplicate(self):
        """Gets the duplicate of this ModelField.  # noqa: E501

        Set to True to use previous value when the field is created.  # noqa: E501

        :return: The duplicate of this ModelField.  # noqa: E501
        :rtype: bool
        """
        return self._duplicate

    @duplicate.setter
    def duplicate(self, duplicate):
        """Sets the duplicate of this ModelField.

        Set to True to use previous value when the field is created.  # noqa: E501

        :param duplicate: The duplicate of this ModelField.  # noqa: E501
        :type: bool
        """

        self._duplicate = duplicate

    @property
    def is_computed_field(self):
        """Gets the is_computed_field of this ModelField.  # noqa: E501

        Set to True for a computed field.  WARNING: Computed fields may be computed for all events.   This could take a long time depending on your database size (from few minutes to several hours) and this will overload the server.  # noqa: E501

        :return: The is_computed_field of this ModelField.  # noqa: E501
        :rtype: bool
        """
        return self._is_computed_field

    @is_computed_field.setter
    def is_computed_field(self, is_computed_field):
        """Sets the is_computed_field of this ModelField.

        Set to True for a computed field.  WARNING: Computed fields may be computed for all events.   This could take a long time depending on your database size (from few minutes to several hours) and this will overload the server.  # noqa: E501

        :param is_computed_field: The is_computed_field of this ModelField.  # noqa: E501
        :type: bool
        """

        self._is_computed_field = is_computed_field

    @property
    def calcul_type(self):
        """Gets the calcul_type of this ModelField.  # noqa: E501

        The calculation type for a computed field.  # noqa: E501

        :return: The calcul_type of this ModelField.  # noqa: E501
        :rtype: str
        """
        return self._calcul_type

    @calcul_type.setter
    def calcul_type(self, calcul_type):
        """Sets the calcul_type of this ModelField.

        The calculation type for a computed field.  # noqa: E501

        :param calcul_type: The calcul_type of this ModelField.  # noqa: E501
        :type: str
        """
        allowed_values = ["Min", "Max", "Avg", "Sum", "UseScript", "First", "Last", "FollowingDifferenceByTag"]  # noqa: E501
        if (self._configuration.client_side_validation and
                calcul_type not in allowed_values):
            raise ValueError(
                "Invalid value for `calcul_type` ({0}), must be one of {1}"  # noqa: E501
                .format(calcul_type, allowed_values)
            )

        self._calcul_type = calcul_type

    @property
    def target_model_field_id(self):
        """Gets the target_model_field_id of this ModelField.  # noqa: E501

        The model field id used for calculation of a computed field.  # noqa: E501

        :return: The target_model_field_id of this ModelField.  # noqa: E501
        :rtype: str
        """
        return self._target_model_field_id

    @target_model_field_id.setter
    def target_model_field_id(self, target_model_field_id):
        """Sets the target_model_field_id of this ModelField.

        The model field id used for calculation of a computed field.  # noqa: E501

        :param target_model_field_id: The target_model_field_id of this ModelField.  # noqa: E501
        :type: str
        """

        self._target_model_field_id = target_model_field_id

    @property
    def export_value_name(self):
        """Gets the export_value_name of this ModelField.  # noqa: E501

        Name of the value for the file export.  # noqa: E501

        :return: The export_value_name of this ModelField.  # noqa: E501
        :rtype: str
        """
        return self._export_value_name

    @export_value_name.setter
    def export_value_name(self, export_value_name):
        """Sets the export_value_name of this ModelField.

        Name of the value for the file export.  # noqa: E501

        :param export_value_name: The export_value_name of this ModelField.  # noqa: E501
        :type: str
        """

        self._export_value_name = export_value_name

    @property
    def export_constant_file_name(self):
        """Gets the export_constant_file_name of this ModelField.  # noqa: E501

        Name of the value for the file export.  # noqa: E501

        :return: The export_constant_file_name of this ModelField.  # noqa: E501
        :rtype: str
        """
        return self._export_constant_file_name

    @export_constant_file_name.setter
    def export_constant_file_name(self, export_constant_file_name):
        """Sets the export_constant_file_name of this ModelField.

        Name of the value for the file export.  # noqa: E501

        :param export_constant_file_name: The export_constant_file_name of this ModelField.  # noqa: E501
        :type: str
        """

        self._export_constant_file_name = export_constant_file_name

    @property
    def list_id(self):
        """Gets the list_id of this ModelField.  # noqa: E501

        The id of the list which is used for a List Selector field.  # noqa: E501

        :return: The list_id of this ModelField.  # noqa: E501
        :rtype: str
        """
        return self._list_id

    @list_id.setter
    def list_id(self, list_id):
        """Sets the list_id of this ModelField.

        The id of the list which is used for a List Selector field.  # noqa: E501

        :param list_id: The list_id of this ModelField.  # noqa: E501
        :type: str
        """

        self._list_id = list_id

    @property
    def item_list_can_be_add(self):
        """Gets the item_list_can_be_add of this ModelField.  # noqa: E501

        True if an item can be added locally.  # noqa: E501

        :return: The item_list_can_be_add of this ModelField.  # noqa: E501
        :rtype: bool
        """
        return self._item_list_can_be_add

    @item_list_can_be_add.setter
    def item_list_can_be_add(self, item_list_can_be_add):
        """Sets the item_list_can_be_add of this ModelField.

        True if an item can be added locally.  # noqa: E501

        :param item_list_can_be_add: The item_list_can_be_add of this ModelField.  # noqa: E501
        :type: bool
        """

        self._item_list_can_be_add = item_list_can_be_add

    @property
    def revision_selector_param(self):
        """Gets the revision_selector_param of this ModelField.  # noqa: E501

        List of Target/Group for revisions selection in the views.  # noqa: E501

        :return: The revision_selector_param of this ModelField.  # noqa: E501
        :rtype: list[CoupleGuidText]
        """
        return self._revision_selector_param

    @revision_selector_param.setter
    def revision_selector_param(self, revision_selector_param):
        """Sets the revision_selector_param of this ModelField.

        List of Target/Group for revisions selection in the views.  # noqa: E501

        :param revision_selector_param: The revision_selector_param of this ModelField.  # noqa: E501
        :type: list[CoupleGuidText]
        """

        self._revision_selector_param = revision_selector_param

    @property
    def revision_selector_show_only_group_rev(self):
        """Gets the revision_selector_show_only_group_rev of this ModelField.  # noqa: E501

        Set to True to show only group revisions in revisions list.  # noqa: E501

        :return: The revision_selector_show_only_group_rev of this ModelField.  # noqa: E501
        :rtype: bool
        """
        return self._revision_selector_show_only_group_rev

    @revision_selector_show_only_group_rev.setter
    def revision_selector_show_only_group_rev(self, revision_selector_show_only_group_rev):
        """Sets the revision_selector_show_only_group_rev of this ModelField.

        Set to True to show only group revisions in revisions list.  # noqa: E501

        :param revision_selector_show_only_group_rev: The revision_selector_show_only_group_rev of this ModelField.  # noqa: E501
        :type: bool
        """

        self._revision_selector_show_only_group_rev = revision_selector_show_only_group_rev

    @property
    def revision_editor_display_format(self):
        """Gets the revision_editor_display_format of this ModelField.  # noqa: E501

        The revision editor display format.  # noqa: E501

        :return: The revision_editor_display_format of this ModelField.  # noqa: E501
        :rtype: str
        """
        return self._revision_editor_display_format

    @revision_editor_display_format.setter
    def revision_editor_display_format(self, revision_editor_display_format):
        """Sets the revision_editor_display_format of this ModelField.

        The revision editor display format.  # noqa: E501

        :param revision_editor_display_format: The revision_editor_display_format of this ModelField.  # noqa: E501
        :type: str
        """
        allowed_values = ["NumericBox", "TextBox", "NumericMultiDim", "TextMultiDim"]  # noqa: E501
        if (self._configuration.client_side_validation and
                revision_editor_display_format not in allowed_values):
            raise ValueError(
                "Invalid value for `revision_editor_display_format` ({0}), must be one of {1}"  # noqa: E501
                .format(revision_editor_display_format, allowed_values)
            )

        self._revision_editor_display_format = revision_editor_display_format

    @property
    def script_content(self):
        """Gets the script_content of this ModelField.  # noqa: E501

        The Python script content.  # noqa: E501

        :return: The script_content of this ModelField.  # noqa: E501
        :rtype: str
        """
        return self._script_content

    @script_content.setter
    def script_content(self, script_content):
        """Sets the script_content of this ModelField.

        The Python script content.  # noqa: E501

        :param script_content: The script_content of this ModelField.  # noqa: E501
        :type: str
        """

        self._script_content = script_content

    @property
    def use_invalid_lap_for_calculation(self):
        """Gets the use_invalid_lap_for_calculation of this ModelField.  # noqa: E501

        Set to True to allow invalid laps in calculations.  # noqa: E501

        :return: The use_invalid_lap_for_calculation of this ModelField.  # noqa: E501
        :rtype: bool
        """
        return self._use_invalid_lap_for_calculation

    @use_invalid_lap_for_calculation.setter
    def use_invalid_lap_for_calculation(self, use_invalid_lap_for_calculation):
        """Sets the use_invalid_lap_for_calculation of this ModelField.

        Set to True to allow invalid laps in calculations.  # noqa: E501

        :param use_invalid_lap_for_calculation: The use_invalid_lap_for_calculation of this ModelField.  # noqa: E501
        :type: bool
        """

        self._use_invalid_lap_for_calculation = use_invalid_lap_for_calculation

    @property
    def tags(self):
        """Gets the tags of this ModelField.  # noqa: E501

        Tags associated with the model field.  # noqa: E501

        :return: The tags of this ModelField.  # noqa: E501
        :rtype: str
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this ModelField.

        Tags associated with the model field.  # noqa: E501

        :param tags: The tags of this ModelField.  # noqa: E501
        :type: str
        """

        self._tags = tags

    @property
    def default_value(self):
        """Gets the default_value of this ModelField.  # noqa: E501

        The default value.  # noqa: E501

        :return: The default_value of this ModelField.  # noqa: E501
        :rtype: object
        """
        return self._default_value

    @default_value.setter
    def default_value(self, default_value):
        """Sets the default_value of this ModelField.

        The default value.  # noqa: E501

        :param default_value: The default_value of this ModelField.  # noqa: E501
        :type: object
        """

        self._default_value = default_value

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ModelField, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ModelField):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ModelField):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Trackside Software TeamDB API v2.0

    This API enables you to access TeamDB data  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@trackside.fr
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from teamdbapi.api_client import ApiClient


class LapReportApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def lap_report_disable_lap_report_reading(self, **kwargs):  # noqa: E501
        """[Command] Disables the lap report reading  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lap_report_disable_lap_report_reading(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.lap_report_disable_lap_report_reading_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.lap_report_disable_lap_report_reading_with_http_info(**kwargs)  # noqa: E501
            return data

    def lap_report_disable_lap_report_reading_with_http_info(self, **kwargs):  # noqa: E501
        """[Command] Disables the lap report reading  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lap_report_disable_lap_report_reading_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method lap_report_disable_lap_report_reading" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/disablelapreportreading', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def lap_report_enable_lap_report_reading(self, **kwargs):  # noqa: E501
        """[Command] Enables the lap report reading  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lap_report_enable_lap_report_reading(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.lap_report_enable_lap_report_reading_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.lap_report_enable_lap_report_reading_with_http_info(**kwargs)  # noqa: E501
            return data

    def lap_report_enable_lap_report_reading_with_http_info(self, **kwargs):  # noqa: E501
        """[Command] Enables the lap report reading  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lap_report_enable_lap_report_reading_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method lap_report_enable_lap_report_reading" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/enablelapreportreading', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def lap_report_get_lap_report_options(self, **kwargs):  # noqa: E501
        """Get the current lap report options  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lap_report_get_lap_report_options(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: LapReportOptions
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.lap_report_get_lap_report_options_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.lap_report_get_lap_report_options_with_http_info(**kwargs)  # noqa: E501
            return data

    def lap_report_get_lap_report_options_with_http_info(self, **kwargs):  # noqa: E501
        """Get the current lap report options  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lap_report_get_lap_report_options_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: LapReportOptions
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method lap_report_get_lap_report_options" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/LapReportOptions', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='LapReportOptions',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def lap_report_load_lap_report(self, file_path, lap_report_file_format, **kwargs):  # noqa: E501
        """Load a full lap report  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lap_report_load_lap_report(file_path, lap_report_file_format, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str file_path: The lap report path (required)
        :param str lap_report_file_format: The lap report file format: Wintax or Atlas (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.lap_report_load_lap_report_with_http_info(file_path, lap_report_file_format, **kwargs)  # noqa: E501
        else:
            (data) = self.lap_report_load_lap_report_with_http_info(file_path, lap_report_file_format, **kwargs)  # noqa: E501
            return data

    def lap_report_load_lap_report_with_http_info(self, file_path, lap_report_file_format, **kwargs):  # noqa: E501
        """Load a full lap report  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lap_report_load_lap_report_with_http_info(file_path, lap_report_file_format, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str file_path: The lap report path (required)
        :param str lap_report_file_format: The lap report file format: Wintax or Atlas (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['file_path', 'lap_report_file_format']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method lap_report_load_lap_report" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'file_path' is set
        if self.api_client.client_side_validation and ('file_path' not in params or
                                                       params['file_path'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `file_path` when calling `lap_report_load_lap_report`")  # noqa: E501
        # verify the required parameter 'lap_report_file_format' is set
        if self.api_client.client_side_validation and ('lap_report_file_format' not in params or
                                                       params['lap_report_file_format'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `lap_report_file_format` when calling `lap_report_load_lap_report`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'file_path' in params:
            query_params.append(('filePath', params['file_path']))  # noqa: E501
        if 'lap_report_file_format' in params:
            query_params.append(('lapReportFileFormat', params['lap_report_file_format']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/loadlapreport', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def lap_report_set_lap_report_options(self, options, **kwargs):  # noqa: E501
        """[Command] Set the lap report options  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lap_report_set_lap_report_options(options, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param LapReportOptions options: The lap report options (isSingleMode, file format, file path) (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.lap_report_set_lap_report_options_with_http_info(options, **kwargs)  # noqa: E501
        else:
            (data) = self.lap_report_set_lap_report_options_with_http_info(options, **kwargs)  # noqa: E501
            return data

    def lap_report_set_lap_report_options_with_http_info(self, options, **kwargs):  # noqa: E501
        """[Command] Set the lap report options  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lap_report_set_lap_report_options_with_http_info(options, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param LapReportOptions options: The lap report options (isSingleMode, file format, file path) (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['options']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method lap_report_set_lap_report_options" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'options' is set
        if self.api_client.client_side_validation and ('options' not in params or
                                                       params['options'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `options` when calling `lap_report_set_lap_report_options`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'options' in params:
            body_params = params['options']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json-patch+json', 'application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/lapreportoptions', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Trackside Software TeamDB API v2.0

    This API enables you to access TeamDB data  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@trackside.fr
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from teamdbapi.api_client import ApiClient


class EditApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def edit_copy_from_tag(self, tag, copy_from_tags_args, **kwargs):  # noqa: E501
        """[Command] Copy values corresponding to the given Tag from a context to another  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.edit_copy_from_tag(tag, copy_from_tags_args, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str tag: The tag corresponding to the values you want to copy (required)
        :param CopyFromTagsArgs copy_from_tags_args: The source and target context (event, car, session, run, lap) from which you want to copy the values (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.edit_copy_from_tag_with_http_info(tag, copy_from_tags_args, **kwargs)  # noqa: E501
        else:
            (data) = self.edit_copy_from_tag_with_http_info(tag, copy_from_tags_args, **kwargs)  # noqa: E501
            return data

    def edit_copy_from_tag_with_http_info(self, tag, copy_from_tags_args, **kwargs):  # noqa: E501
        """[Command] Copy values corresponding to the given Tag from a context to another  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.edit_copy_from_tag_with_http_info(tag, copy_from_tags_args, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str tag: The tag corresponding to the values you want to copy (required)
        :param CopyFromTagsArgs copy_from_tags_args: The source and target context (event, car, session, run, lap) from which you want to copy the values (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['tag', 'copy_from_tags_args']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method edit_copy_from_tag" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'tag' is set
        if self.api_client.client_side_validation and ('tag' not in params or
                                                       params['tag'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `tag` when calling `edit_copy_from_tag`")  # noqa: E501
        # verify the required parameter 'copy_from_tags_args' is set
        if self.api_client.client_side_validation and ('copy_from_tags_args' not in params or
                                                       params['copy_from_tags_args'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `copy_from_tags_args` when calling `edit_copy_from_tag`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'tag' in params:
            path_params['tag'] = params['tag']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'copy_from_tags_args' in params:
            body_params = params['copy_from_tags_args']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json-patch+json', 'application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/tag/{tag}/copy', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def edit_get_current_car_parameters_selected_context(self, **kwargs):  # noqa: E501
        """Get the current Car Parameters selected context in Parameters Editor view  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.edit_get_current_car_parameters_selected_context(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: CarParametersContext
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.edit_get_current_car_parameters_selected_context_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.edit_get_current_car_parameters_selected_context_with_http_info(**kwargs)  # noqa: E501
            return data

    def edit_get_current_car_parameters_selected_context_with_http_info(self, **kwargs):  # noqa: E501
        """Get the current Car Parameters selected context in Parameters Editor view  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.edit_get_current_car_parameters_selected_context_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: CarParametersContext
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method edit_get_current_car_parameters_selected_context" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/currentCarParametersContext', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CarParametersContext',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def edit_get_current_selected_context(self, **kwargs):  # noqa: E501
        """Get the current selected notes context  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.edit_get_current_selected_context(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: NotesContext
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.edit_get_current_selected_context_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.edit_get_current_selected_context_with_http_info(**kwargs)  # noqa: E501
            return data

    def edit_get_current_selected_context_with_http_info(self, **kwargs):  # noqa: E501
        """Get the current selected notes context  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.edit_get_current_selected_context_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: NotesContext
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method edit_get_current_selected_context" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/currentcontext', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='NotesContext',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def edit_set_current_context(self, event_id, car_id, session_id, run_id, lap_id, **kwargs):  # noqa: E501
        """[Command] Set the current Event, Car, Session, Run, Lap selected.  Enter the empty unique identifier value 00000000-0000-0000-0000-000000000000 to select the default value.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.edit_set_current_context(event_id, car_id, session_id, run_id, lap_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str event_id: The event unique id to select (required)
        :param str car_id: The car unique id to select (required)
        :param str session_id: The session unique id to select (required)
        :param str run_id: The run unique id to select (required)
        :param str lap_id: The lap unique id to select (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.edit_set_current_context_with_http_info(event_id, car_id, session_id, run_id, lap_id, **kwargs)  # noqa: E501
        else:
            (data) = self.edit_set_current_context_with_http_info(event_id, car_id, session_id, run_id, lap_id, **kwargs)  # noqa: E501
            return data

    def edit_set_current_context_with_http_info(self, event_id, car_id, session_id, run_id, lap_id, **kwargs):  # noqa: E501
        """[Command] Set the current Event, Car, Session, Run, Lap selected.  Enter the empty unique identifier value 00000000-0000-0000-0000-000000000000 to select the default value.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.edit_set_current_context_with_http_info(event_id, car_id, session_id, run_id, lap_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str event_id: The event unique id to select (required)
        :param str car_id: The car unique id to select (required)
        :param str session_id: The session unique id to select (required)
        :param str run_id: The run unique id to select (required)
        :param str lap_id: The lap unique id to select (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['event_id', 'car_id', 'session_id', 'run_id', 'lap_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method edit_set_current_context" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'event_id' is set
        if self.api_client.client_side_validation and ('event_id' not in params or
                                                       params['event_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `event_id` when calling `edit_set_current_context`")  # noqa: E501
        # verify the required parameter 'car_id' is set
        if self.api_client.client_side_validation and ('car_id' not in params or
                                                       params['car_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `car_id` when calling `edit_set_current_context`")  # noqa: E501
        # verify the required parameter 'session_id' is set
        if self.api_client.client_side_validation and ('session_id' not in params or
                                                       params['session_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `session_id` when calling `edit_set_current_context`")  # noqa: E501
        # verify the required parameter 'run_id' is set
        if self.api_client.client_side_validation and ('run_id' not in params or
                                                       params['run_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `run_id` when calling `edit_set_current_context`")  # noqa: E501
        # verify the required parameter 'lap_id' is set
        if self.api_client.client_side_validation and ('lap_id' not in params or
                                                       params['lap_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `lap_id` when calling `edit_set_current_context`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'event_id' in params:
            query_params.append(('eventId', params['event_id']))  # noqa: E501
        if 'car_id' in params:
            query_params.append(('carId', params['car_id']))  # noqa: E501
        if 'session_id' in params:
            query_params.append(('sessionId', params['session_id']))  # noqa: E501
        if 'run_id' in params:
            query_params.append(('runId', params['run_id']))  # noqa: E501
        if 'lap_id' in params:
            query_params.append(('lapId', params['lap_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/currentcontext', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)
